UpsellWrapperWidget class

A wrapper widget that handles the asynchronous fetching of download status and then displays the appropriate UI. Fetching download status should be nearly synchronous.

Inheritance

Constructors

UpsellWrapperWidget({Key? key, required String trigger, required Widget paywallNotShownReplacement, required Future<CanPresentUpsellResult?> availabilityChecker(), Map<String, dynamic>? customPaywallTraits, void onFallbackOpened(String? paywallUnavailableReason)?, VoidCallback? onFallbackClosed})
const

Properties

availabilityChecker Future<CanPresentUpsellResult?> Function()
final
customPaywallTraits Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFallbackClosed VoidCallback?
final
onFallbackOpened → void Function(String? paywallUnavailableReason)?
final
paywallNotShownReplacement Widget
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<UpsellWrapperWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited