CustomPaywallActionEvent class

Constructors

CustomPaywallActionEvent({required String triggerName, required String paywallName, required String actionName, required Map<String, dynamic> params, required bool isSecondTry})

Properties

actionName → String
final
hashCode → int
The hash code for this object.
no setterinherited
isSecondTry → bool
final
params → Map<String, dynamic>
final
paywallName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerName → String
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited