PaywallOpenFailedEvent class

Constructors

PaywallOpenFailedEvent({required String triggerName, required String paywallName, required String error, required String? paywallUnavailableReason, required bool isSecondTry, int? loadTimeTakenMS, int? loadingBudgetMS})

Properties

error String
final
hashCode int
The hash code for this object.
no setterinherited
isSecondTry bool
final
loadingBudgetMS int?
Loading budget configured for the trigger, in milliseconds.
final
loadTimeTakenMS int?
Time the loading state was shown for before the failure, in milliseconds.
final
paywallName String
final
paywallUnavailableReason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerName String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited