HeliumPaywallEvent class
Constructors
-
HeliumPaywallEvent.fromMap(Map<
String, dynamic> map)
Properties
- bundleDownloadTimeMS → int?
-
no setter
-
no setter
- canonicalJoinTransactionId → String?
-
no setter
- configDownloadTimeMs → int?
-
no setter
- configId → String?
-
no setter
- ctaName → String?
-
@deprecated Use
buttonNameinstead.no setter - customPaywallActionName → String?
-
no setter
-
customPaywallActionParams
→ Map<
String, dynamic> ? -
no setter
- dismissAll → bool?
-
no setter
- error → String?
-
no setter
- errorDescription → String?
-
@deprecated Use
errorinstead.no setter - fontsDownloadTimeTakenMS → int?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- impressionId → String?
-
no setter
- isSecondTry → bool?
-
no setter
- loadingBudgetMS → int?
-
Loading budget for the trigger, in milliseconds. Present on
paywallOpen/paywallOpenFailed.no setter - loadTimeTakenMS → int?
-
Time the loading state was shown for, in milliseconds. Present on
paywallOpen/paywallOpenFailedwhen a loading state was used.no setter - origin → PurchaseRestoredOrigin?
-
How an existing entitlement was surfaced. Present on
purchaseRestoredevents.no setter - paymentProcessor → HeliumPaymentProcessor?
-
no setter
- paywallName → String?
-
no setter
- paywallTemplateName → String?
-
@deprecated Use
paywallNameinstead.no setter -
no setter
- productId → String?
-
no setter
- productKey → String?
-
@deprecated Use
productIdinstead.no setter -
rawData
→ Map<
String, dynamic> -
no setter
- responseTimeMs → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipReason → PaywallSkippedReason?
-
Reason the paywall was skipped. Present on
paywallSkippedevents.no setter - timestamp → int?
-
Unix timestamp in seconds
no setter
- totalInitializeTimeMS → int?
-
Total time from config fetch start to completion, in milliseconds.
Present on
paywallsDownloadSuccess/paywallsDownloadError.no setter - triggerName → String?
-
no setter
- type → String
-
no setter
Methods
-
getSafeData(
dynamic paramsData) → Map< String, dynamic> ? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited