PaywallOpenEvent class

Constructors

PaywallOpenEvent({required String triggerName, required String paywallName, required bool isSecondTry, String? viewType, String? paywallUnavailableReason, int? loadTimeTakenMS, int? loadingBudgetMS})

Properties

hashCode int
The hash code for this object.
no setterinherited
isSecondTry bool
final
loadingBudgetMS int?
Loading budget configured for the trigger, in milliseconds.
final
loadTimeTakenMS int?
Time the loading state was shown for, in milliseconds. Present when a loading state was used for this trigger.
final
paywallName String
final
paywallUnavailableReason String?
Set when a fallback was shown in place of the configured paywall.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerName String
final
type String
final
viewType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited